==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/model/HostedServiceType.java <==

package org.somda.sdc.dpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for HostedServiceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HostedServiceType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}EndpointReference" maxOccurs="unbounded"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}Types"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}ServiceId"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HostedServiceType", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", propOrder = {
    "endpointReference",
    "types",
    "serviceId",
    "any"
})
public class HostedServiceType implements ToString2
{

    @XmlElement(name = "EndpointReference", namespace = "http://www.w3.org/2005/08/addressing", required = true)
    protected List<EndpointReferenceType> endpointReference;
    @XmlList
    @XmlElement(name = "Types", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    protected List<QName> types;
    @XmlElement(name = "ServiceId", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String serviceId;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the endpointReference property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the endpointReference property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEndpointReference().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link EndpointReferenceType }
     * 
     * 
     */
    public List<EndpointReferenceType> getEndpointReference() {
        if (endpointReference == null) {
            endpointReference = new ArrayList<EndpointReferenceType>();
        }
        return this.endpointReference;
    }

    /**
     * Gets the value of the types property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the types property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTypes().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QName }
     * 
     * 
     */
    public List<QName> getTypes() {
        if (types == null) {
            types = new ArrayList<QName>();
        }
        return this.types;
    }

    /**
     * Ruft den Wert der serviceId-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getServiceId() {
        return serviceId;
    }

    /**
     * Legt den Wert der serviceId-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setServiceId(String value) {
        this.serviceId = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setEndpointReference(List<EndpointReferenceType> value) {
        this.endpointReference = null;
        if (value!= null) {
            List<EndpointReferenceType> draftl = this.getEndpointReference();
            draftl.addAll(value);
        }
    }

    public void setTypes(List<QName> value) {
        this.types = null;
        if (value!= null) {
            List<QName> draftl = this.getTypes();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final HostedServiceType that = ((HostedServiceType) object);
        {
            List<EndpointReferenceType> leftEndpointReference;
            leftEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            List<EndpointReferenceType> rightEndpointReference;
            rightEndpointReference = (((that.endpointReference!= null)&&(!that.endpointReference.isEmpty()))?that.getEndpointReference():null);
            if ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())) {
                if ((that.endpointReference!= null)&&(!that.endpointReference.isEmpty())) {
                    if (!leftEndpointReference.equals(rightEndpointReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.endpointReference!= null)&&(!that.endpointReference.isEmpty())) {
                    return false;
                }
            }
        }
        {
            List<QName> leftTypes;
            leftTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            List<QName> rightTypes;
            rightTypes = (((that.types!= null)&&(!that.types.isEmpty()))?that.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    if (!leftTypes.equals(rightTypes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftServiceId;
            leftServiceId = this.getServiceId();
            String rightServiceId;
            rightServiceId = that.getServiceId();
            if (this.serviceId!= null) {
                if (that.serviceId!= null) {
                    if (!leftServiceId.equals(rightServiceId)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.serviceId!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<EndpointReferenceType> theEndpointReference;
            theEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            if ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())) {
                currentHashCode += theEndpointReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                currentHashCode += theTypes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theServiceId;
            theServiceId = this.getServiceId();
            if (this.serviceId!= null) {
                currentHashCode += theServiceId.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<EndpointReferenceType> theEndpointReference;
            theEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            strategy.appendField(locator, this, "endpointReference", buffer, theEndpointReference, ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())));
        }
        {
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            strategy.appendField(locator, this, "types", buffer, theTypes, ((this.types!= null)&&(!this.types.isEmpty())));
        }
        {
            String theServiceId;
            theServiceId = this.getServiceId();
            strategy.appendField(locator, this, "serviceId", buffer, theServiceId, (this.serviceId!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/model/HostedServiceType.java <==

package org.somda.sdc.dpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlList;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for HostedServiceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HostedServiceType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}EndpointReference" maxOccurs="unbounded"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}Types"/&gt;
 *         &lt;element ref="{http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01}ServiceId"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HostedServiceType", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", propOrder = {
    "endpointReference",
    "types",
    "serviceId",
    "any"
})
public class HostedServiceType implements ToString2
{

    @XmlElement(name = "EndpointReference", namespace = "http://www.w3.org/2005/08/addressing", required = true)
    protected List<EndpointReferenceType> endpointReference;
    @XmlList
    @XmlElement(name = "Types", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    protected List<QName> types;
    @XmlElement(name = "ServiceId", namespace = "http://docs.oasis-open.org/ws-dd/ns/dpws/2009/01", required = true)
    @XmlSchemaType(name = "anyURI")
    protected String serviceId;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the endpointReference property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the endpointReference property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getEndpointReference().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link EndpointReferenceType }
     * 
     * 
     */
    public List<EndpointReferenceType> getEndpointReference() {
        if (endpointReference == null) {
            endpointReference = new ArrayList<EndpointReferenceType>();
        }
        return this.endpointReference;
    }

    /**
     * Gets the value of the types property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the types property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTypes().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link QName }
     * 
     * 
     */
    public List<QName> getTypes() {
        if (types == null) {
            types = new ArrayList<QName>();
        }
        return this.types;
    }

    /**
     * Gets the value of the serviceId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getServiceId() {
        return serviceId;
    }

    /**
     * Sets the value of the serviceId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setServiceId(String value) {
        this.serviceId = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setEndpointReference(List<EndpointReferenceType> value) {
        this.endpointReference = null;
        if (value!= null) {
            List<EndpointReferenceType> draftl = this.getEndpointReference();
            draftl.addAll(value);
        }
    }

    public void setTypes(List<QName> value) {
        this.types = null;
        if (value!= null) {
            List<QName> draftl = this.getTypes();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final HostedServiceType that = ((HostedServiceType) object);
        {
            List<EndpointReferenceType> leftEndpointReference;
            leftEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            List<EndpointReferenceType> rightEndpointReference;
            rightEndpointReference = (((that.endpointReference!= null)&&(!that.endpointReference.isEmpty()))?that.getEndpointReference():null);
            if ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())) {
                if ((that.endpointReference!= null)&&(!that.endpointReference.isEmpty())) {
                    if (!leftEndpointReference.equals(rightEndpointReference)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.endpointReference!= null)&&(!that.endpointReference.isEmpty())) {
                    return false;
                }
            }
        }
        {
            List<QName> leftTypes;
            leftTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            List<QName> rightTypes;
            rightTypes = (((that.types!= null)&&(!that.types.isEmpty()))?that.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    if (!leftTypes.equals(rightTypes)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.types!= null)&&(!that.types.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftServiceId;
            leftServiceId = this.getServiceId();
            String rightServiceId;
            rightServiceId = that.getServiceId();
            if (this.serviceId!= null) {
                if (that.serviceId!= null) {
                    if (!leftServiceId.equals(rightServiceId)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.serviceId!= null) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            List<EndpointReferenceType> theEndpointReference;
            theEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            if ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())) {
                currentHashCode += theEndpointReference.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            if ((this.types!= null)&&(!this.types.isEmpty())) {
                currentHashCode += theTypes.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theServiceId;
            theServiceId = this.getServiceId();
            if (this.serviceId!= null) {
                currentHashCode += theServiceId.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            List<EndpointReferenceType> theEndpointReference;
            theEndpointReference = (((this.endpointReference!= null)&&(!this.endpointReference.isEmpty()))?this.getEndpointReference():null);
            strategy.appendField(locator, this, "endpointReference", buffer, theEndpointReference, ((this.endpointReference!= null)&&(!this.endpointReference.isEmpty())));
        }
        {
            List<QName> theTypes;
            theTypes = (((this.types!= null)&&(!this.types.isEmpty()))?this.getTypes():null);
            strategy.appendField(locator, this, "types", buffer, theTypes, ((this.types!= null)&&(!this.types.isEmpty())));
        }
        {
            String theServiceId;
            theServiceId = this.getServiceId();
            strategy.appendField(locator, this, "serviceId", buffer, theServiceId, (this.serviceId!= null));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
